@@ -452,6 +452,15 @@ static int wanec_enable(void *pcard, int enable, int fe_chan)
    		return -EINVAL; 		
 	}
 
+	if (ec_dev->state != WAN_EC_STATE_CHIP_OPEN &&
+	    ec_dev->state != WAN_EC_STATE_CHIP_READY){            
+        if (WAN_NET_RATELIMIT()) {
+			DEBUG_EVENT("%s: Failed to enable ec chip is not ready!\n",
+			ec->name);
+		}
+   		return -EINVAL; 
+	}
+
 #if defined(WANEC_BYDEFAULT_NORMAL)
 	WAN_ASSERT(ec_dev->ec == NULL);
 	wan_spin_lock(&ec_dev->ec->lock);
